@@ -18,7 +18,7 @@ import oead
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
-from . import actorinfo, util
+from . import util
 
 
 physics_ext = {
@@ -39,9 +39,6 @@ class ActorPack:
     _links: dict
     _tags: list
     _misc_tags: list
-    _has_far: bool
-    _needs_info_update: bool
-    _titlebg: bool
 
     def __init__(self) -> None:
         self._actorname = ""
@@ -52,24 +49,16 @@ class ActorPack:
         self._links = {}
         self._tags = []
         self._misc_tags = []
-        self._has_far = False
-        self._needs_info_update = False
-        self._titlebg = False
 
     def from_actor(self, pack: Union[Path, str]) -> None:
         handled_filenames = set()
         if isinstance(pack, str):
-            self._titlebg = True
             pack_nests = pack.split("//")
             pack = Path(pack_nests[-1])
             titlebg = oead.Sarc(Path(pack_nests[0]).read_bytes())
             data = util.unyaz_if_needed(titlebg.get_file(pack_nests[-1]).data)
-            actorinfo_path = (
-                Path(pack_nests[0]).parent / "../Actor/ActorInfo.product.sbyml"
-            ).resolve()
         else:
             data = util.unyaz_if_needed(pack.read_bytes())
-            actorinfo_path = (pack.parent / "../ActorInfo.product.sbyml").resolve()
         self._actorname = pack.stem
         sarcdata = oead.Sarc(data)
 
@@ -112,21 +101,10 @@ class ActorPack:
             if not f.name in handled_filenames:
                 self._miscfiles[f"{f.name}"] = bytes(f.data)
 
-        if not actorinfo_path.exists():
-            actorinfo_path = Path(util.find_file(Path("Actor/ActorInfo.product.sbyml")))
-        actorinfo = oead.byml.from_binary(oead.yaz0.decompress(actorinfo_path.read_bytes()))
-        for actor in actorinfo["Actors"]:
-            if actor["name"] == self._actorname:
-                self._info = actor
-                break
-        del actorinfo
-        del actorinfo_path
-
     def get_name(self) -> str:
         return self._actorname
 
     def set_name(self, name: str) -> None:
-        self._titlebg = False
         for link, linkref in self._links.items():
             if linkref == self._actorname:
                 self._links[link] = name
@@ -151,7 +129,6 @@ class ActorPack:
         self._actorname = name
         if "Armor_" in name and self._links["ModelUser"] == self._actorname:
             mlist = self._aampfiles["ModelUser"]
-        self._needs_info_update = True
 
     def get_link(self, link: str) -> str:
         return self._links[link]
@@ -160,9 +137,6 @@ class ActorPack:
         old_linkref = self._links[link]
         self._links[link] = linkref
 
-        if util._link_to_tab_index(link) == -1:
-            return
-
         if link in util.AAMP_LINK_REFS:
             folder, ext = util.AAMP_LINK_REFS[link]
             if old_linkref == "Dummy":
@@ -175,7 +149,6 @@ class ActorPack:
                 self._bymlfiles[link] = oead.byml.Hash()
             elif linkref == "Dummy":
                 self._bymlfiles.pop(link)
-        self._needs_info_update = True
 
     def get_link_data(self, link: str) -> str:
         linkref = self._links[link]
@@ -191,20 +164,11 @@ class ActorPack:
             self._aampfiles[link] = oead.aamp.ParameterIO.from_text(data)
         elif link in util.BYML_LINK_REFS:
             self._bymlfiles[link] = oead.byml.from_text(data)
-        self._needs_info_update = True
-
-    def get_info(self) -> oead.byml.Hash:
-        if self._needs_info_update:
-            # TODO: This is messy, we shouldn't let someone else directly modify our property
-            actorinfo.generate_actor_info(self, self._info)
-            self._needs_info_update = False
-        return self._info
 
     def get_tags(self) -> str:
         return ", ".join(self._tags)
 
     def set_tags(self, tags: str) -> None:
-        self._needs_info_update = True
         self._tags = [tag for tag in tags.split(", ")]
 
     def get_actorlink(self) -> oead.aamp.ParameterIO:
@@ -222,12 +186,6 @@ class ActorPack:
                     actorlink.objects[key] = tagset[key]
         return actorlink
 
-    def set_has_far(self, has_far: bool) -> None:
-        self._has_far = has_far
-
-    def get_has_far(self) -> bool:
-        return self._has_far
-
     def get_bytes(self, be: bool) -> bytes:
         writer = oead.SarcWriter()
         endianness = oead.Endianness.Big if be else oead.Endianness.Little
